ValidMind Public REST API Reference
Programmatically interact with models, groups, business units, use cases, and templates.
This rendered site is an archived version of the changes last made by Beck, minus some proprietary content from private repos — Visit live site
August 21, 2026
The ValidMind Platform provides a RESTful APIs to programmatically interact with:
https://api.prod.validmind.ai/vm/api/v1/
This version of the API is v1, specified in the path (/vm/api/v1). Future breaking changes will be introduced under a new version path.
All API endpoints require authentication using two headers that must be included with every request:
x-api-key: Your ValidMind API keyx-api-secret: Your ValidMind API secretTo use this cURL example, replace API_KEY and API_SECRET with your own credentials:
curl -X GET "https://api.prod.validmind.ai/vm/api/v1/models" \
-H 'accept: application/json' \
-H 'x-api-key: API_KEY' \
-H 'x-api-secret: API_SECRET'
In the left sidebar, click Settings.
Under Your Account, select Profile.
Under Access Keys:
The APIs follows REST principles and uses JSON for both requests and responses.
application/json.format=csv query parameter.| Code | Meaning |
|---|---|
| 200 | Success |
| 400 | Bad request (validation) |
| 401 | Authentication failed |
| 403 | Authorization failed |
| 404 | Resource not found |
| 500 | Internal server error |